@@ -26,9 +26,10 @@ cardinal <- function(x, max_n = Inf, negative = "negative", ...) {
   numeric <- x
   n       <- length(x)
 
-  if (!n)                 return(character(0))
-  if (!is.numeric(x))     stop("`x` must be numeric")
-  if (!is.numeric(max_n)) stop("`max_n` must be numeric")
+  if (!n)                         return(character(0))
+  if (all(is.na(x) & !is.nan(x))) return(as.character(x))
+  if (!is.numeric(x))             stop("`x` must be numeric")
+  if (!is.numeric(max_n))         stop("`max_n` must be numeric")
   if (length(max_n) != 1 && length(max_n) != n)
     stop("`max_n` must be either length one or the same length as `x`")
   if (!is.character(negative)) stop("`negative` must be of type character")
@@ -39,58 +40,69 @@ cardinal <- function(x, max_n = Inf, negative = "negative", ...) {
   if (length(negative) != n)
     stop("`negative` must be length one or the same length as `x`")
 
-  card                 <- character(n)
-  card[abs(x) > max_n] <- gsub(
-    " ", "", format(x[abs(x) > max_n], scientific = FALSE)
+  finite <- is.finite(x)
+
+  card                          <- character(n)
+  card[finite & abs(x) > max_n] <- str_remove_all(
+    format(x[finite & abs(x) > max_n], scientific = FALSE), " "
   )
 
   unmaxed <- card == character(1)
 
-  minus                  <- character(n)
-  minus[x < 0 & unmaxed] <- paste0(negative[x < 0 & unmaxed], " ")
-  x[unmaxed]             <- abs(x[unmaxed])
+  minus <- character(n)
+  minus[finite & x < 0 & unmaxed] <- paste0(
+    negative[finite & x < 0 & unmaxed], " "
+  )
 
-  if (any(unmaxed)) {
+  x[unmaxed] <- abs(x[unmaxed])
+  finite     <- unmaxed & finite
+
+  if (any(finite)) {
     decimal                <- numeric(n)
-    decimal[unmaxed]       <- x[unmaxed] %% 1
+    decimal[finite]        <- x[finite] %% 1
     fraction               <- character(n)
     fraction[decimal != 0] <- convert_fraction(decimal[decimal != 0], ...)
-    x[unmaxed]             <- x[unmaxed] %/% 1
+    x[finite]              <- x[finite] %/% 1
 
-    x[unmaxed] <- format(x[unmaxed], scientific = FALSE)
-    nchar      <- ceiling(nchar(x[unmaxed][[1]]) / 3) * 3
-    x[unmaxed] <- format(
-      x[unmaxed], justify = "right", width = nchar, scientific = FALSE
+    card[finite] <- format(x[finite], scientific = FALSE)
+    nchar     <- ceiling(nchar(card[finite][[1]]) / 3) * 3
+    card[finite] <- format(
+      card[finite], justify = "right", width = nchar, scientific = FALSE
     )
 
-    n_unmaxed <- sum(unmaxed)
+    n_finite <- sum(finite)
 
     segment <- matrix(
-      rep(x[unmaxed], nchar / 3), ncol = n_unmaxed, byrow = TRUE
+      rep(card[finite], nchar / 3), ncol = n_finite, byrow = TRUE
     )
     segment <- substr(
       segment,
-      rep(seq(1, nchar, 3), n_unmaxed),
-      rep(seq(3, nchar, 3), n_unmaxed)
+      rep(seq(1, nchar, 3), n_finite),
+      rep(seq(3, nchar, 3), n_finite)
     )
     segment <- convert_hundreds(segment)
 
     nrow                 <- nrow(segment)
     power                <- segment
-    power[]              <- rep(powers[seq_len(nrow)], n_unmaxed)
+    power[]              <- rep(powers[seq_len(nrow)], n_finite)
     power                <- power[nrow:1, ]
     power[segment == ""] <- ""
 
-    segment[]                         <- paste0(segment, power)
-    card[unmaxed]                     <- apply(segment, 2, paste, collapse = "")
-    card[card == "" & fraction == ""] <- "zero"
+    segment[]    <- paste0(segment, power)
+    card[finite] <- apply(segment, 2, paste, collapse = "")
+    card[finite & card == "" & fraction == ""] <- "zero"
 
-    and                              <- character(n)
-    and[card != "" & fraction != ""] <- " and "
+    and                                       <- character(n)
+    and[finite & card != "" & fraction != ""] <- " and "
 
-    card <- paste0(minus, trimws(card), and, fraction)
+    card[finite] <- paste0(trimws(card), and, fraction)[finite]
   }
 
+  card[is.infinite(x)] <- "infinity"
+  card                 <- paste0(minus, card)
+  card[is.na(x)]       <- NA
+  card[is.nan(x)]      <- NaN
+
   args        <- as.list(match.call()[-1])
   args[["x"]] <- NULL
 
