@@ -16,9 +16,10 @@
 #' @example examples/denominator.R
 
 denominator <- function(x, numerator = 1, quarter = TRUE, ...) {
-  if (!length(x))              return(character(0))
-  if (!is.numeric(x))          stop("`x` must be numeric")
-  if (!is.numeric(numerator))  stop("`numerator` must be numeric")
+  if (!length(x))                 return(character(0))
+  if (all(is.na(x) & !is.nan(x))) return(as.character(x))
+  if (!is.numeric(x))             stop("`x` must be numeric")
+  if (!is.numeric(numerator))     stop("`numerator` must be numeric")
   if (length(numerator) != 1 & length(numerator) != length(x))
     stop("`numerator` must be either length one or the same length as `x`")
   if (length(quarter) != 1) stop("`quarter` must be length one")
@@ -26,25 +27,35 @@ denominator <- function(x, numerator = 1, quarter = TRUE, ...) {
     stop("`quarter` must be either `TRUE` or `FALSE`")
 
   numeric <- x
+  finite  <- is.finite(x)
   denom   <- ordinal(x, ...)
   plural  <- abs(numerator) != 1
 
-  denom[abs(x) == 1] <- gsub("1st$|first$", "whole", denom[abs(x) == 1])
-
-  denom[abs(x) == 2 & !plural] <- gsub(
-    "2nd$|second$", "half", denom[abs(x) == 2 & !plural]
+  denom[finite & abs(x) == 1] <- str_replace_all(
+    denom[finite & abs(x) == 1], "1st$|first$", "whole"
   )
-  denom[abs(x) == 2 & plural] <- gsub(
-    "2nd$|second$", "halves", denom[abs(x) == 2 & plural]
+
+  denom[finite & abs(x) == 2 & !plural] <- str_replace_all(
+    denom[finite & abs(x) == 2 & !plural], "2nd$|second$", "half"
+  )
+  denom[finite & abs(x) == 2 & plural] <- str_replace_all(
+    denom[finite & abs(x) == 2 & plural], "2nd$|second$", "halves"
   )
 
   if (quarter) {
-    denom[abs(x) == 4] <- gsub("fourth$", "quarter", denom[abs(x) == 4])
+    denom[finite & abs(x) == 4] <- str_replace_all(
+      denom[finite & abs(x) == 4], "fourth$", "quarter"
+    )
   }
 
-  denom[plural & abs(x) != 2] <- paste0(denom[plural & abs(x) != 2], "s")
+  denom[finite & plural & abs(x) != 2] <- paste0(
+    denom[finite & plural & abs(x) != 2], "s"
+  )
 
-  denom <- gsub("^one-", "", denom)
+  denom <- str_remove_all(denom, "^one-")
+
+  denom[is.na(x)]  <- NA
+  denom[is.nan(x)] <- NaN
 
   args        <- as.list(match.call()[-1])
   args[["x"]] <- NULL
