@@ -11,7 +11,7 @@
 #' @export
 
 numerator <- function(x, ...) {
-  if (any(x != x %/% 1)) {
+  if (any(x[is.finite(x)] != x[is.finite(x)] %/% 1)) {
     stop("`x` must not have a decimal component when producing a numerator")
   }
 
